@@ -183,6 +183,7 @@ Output options:
                                    NOTE: Line continues until next wrap point is found.
  -n,  --end-with-newline           End output with newline
  --indent-empty-lines              Keep indentation on empty lines
+ --templating                      List of templating languages (auto,none,django,erb,handlebars,php) ["auto"] auto = none in JavaScript, all in html
  --editorconfig                    Enable setting configuration from EditorConfig
 
 Rarely needed options:
@@ -237,7 +238,7 @@ def main():
                                     'brace-style=', 'indent-level=', 'unescape-strings',
                                     'help', 'usage', 'stdin', 'eval-code', 'indent-with-tabs', 'keep-function-indentation', 'version',
                                     'e4x', 'end-with-newline', 'comma-first', 'operator-position=', 'wrap-line-length', 'editorconfig', 'space-after-named-function',
-                                    'keep-array-indentation', 'indent-empty-lines'])
+                                    'keep-array-indentation', 'indent-empty-lines', 'templating'])
     except getopt.GetoptError as ex:
         print(ex, file=sys.stderr)
         return usage(sys.stderr)
@@ -299,6 +300,8 @@ def main():
             js_options.wrap_line_length = int(arg)
         elif opt in ('--indent-empty-lines'):
             js_options.indent_empty_lines = True
+        elif opt in ('--templating'):
+            js_options.templating = arg.split(',')
         elif opt in ('--stdin', '-i'):
             # stdin is the default if no files are passed
             filepath_params = []
